pub struct SuiteRunnerProxy { /* private fields */ }Implementations
Sourceimpl SuiteRunnerProxy
impl SuiteRunnerProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.test.manager/SuiteRunner.
Sourcepub fn take_event_stream(&self) -> SuiteRunnerEventStream
pub fn take_event_stream(&self) -> SuiteRunnerEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn run(
&self,
test_suite_url: &str,
options: RunSuiteOptions,
controller: ServerEnd<SuiteControllerMarker>,
) -> Result<(), Error>
pub fn run( &self, test_suite_url: &str, options: RunSuiteOptions, controller: ServerEnd<SuiteControllerMarker>, ) -> Result<(), Error>
Run a test suite. A suite is a test component that implements fuchsia.test.Suite.